# pyHOC
Calculates higher order crossings of a signal, referred from the paper "Discrimination analysis of discontinuous breath sounds using higher-order crossings" authored by  L. J. Hadjileontiadis
